@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,7 +25,7 @@ class RichTextComposerActionsTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit RichTextComposerActionsTest(QObject *parent = Q_NULLPTR);
+    explicit RichTextComposerActionsTest(QObject *parent = nullptr);
     ~RichTextComposerActionsTest();
 private Q_SLOTS:
     void shouldHaveDefaultValue();
