@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -35,6 +35,7 @@
 #include <kpimtextedit/richtextcomposercontroler.h>
 #include <kpimtextedit/richtextcomposerimages.h>
 #include <kpimtextedit/richtextcomposer.h>
+#include <QStandardPaths>
 
 using namespace KPIMTextEdit;
 
@@ -43,11 +44,12 @@ RichTextComposerTest::RichTextComposerTest(QObject *parent)
     : QObject(parent)
 {
     qRegisterMetaType<KPIMTextEdit::RichTextComposer::Mode>();
+    QIcon::setThemeName(QStringLiteral("breeze"));
+    QStandardPaths::setTestModeEnabled(true);
 }
 
 RichTextComposerTest::~RichTextComposerTest()
 {
-
 }
 
 void RichTextComposerTest::testFormattingUsed()
@@ -469,12 +471,16 @@ void RichTextComposerTest::testWrappedPlainText_data()
     QTest::addColumn<QString>("input");
     QTest::addColumn<QString>("output");
 
-    QString defaultStr = QStringLiteral("http://example.org/test-test-test-test-test-test-test-test-test-test-test-test-test\n  https://example.org/test-test-test-test-test-test-test-test-test-test-test-test-test\ntest ftp://example.org/test-test-test-test-test-test-test-test-test-test-test-test-test\nftps://example.org/test-test-test-test-test-test-test-test-test-test-test-test-test\n  ldap://example.org/test-test-test-test-test-test-test-test-test-test-test-test-test");
+    QString defaultStr = QStringLiteral(
+        "http://example.org/test-test-test-test-test-test-test-test-test-test-test-test-test\n  https://example.org/test-test-test-test-test-test-test-test-test-test-test-test-test\ntest ftp://example.org/test-test-test-test-test-test-test-test-test-test-test-test-test\nftps://example.org/test-test-test-test-test-test-test-test-test-test-test-test-test\n  ldap://example.org/test-test-test-test-test-test-test-test-test-test-test-test-test");
     QTest::newRow("default") << defaultStr << defaultStr;
     QTest::newRow("empty") << QString() << QString();
-    QTest::newRow("wrap") << QStringLiteral("foosdfsdf sdsf sdfsdfsfs fsf sdfs df sfsdf dsf sdfsdf sf sf sfsdf sdsdf") << QStringLiteral("foosdfsdf sdsf sdfsdfsfs fsf sdfs df sfsdf \ndsf sdfsdf sf sf sfsdf sdsdf");
-    QTest::newRow("wrap-2") << QStringLiteral("test-test-test-test-test-test-test-test-test-test-test-test-test") << QStringLiteral("test-test-test-test-test-test-test-test-test-\ntest-test-test-test");
-    QTest::newRow("wrap-3") << QStringLiteral("test-test-test-test-test-test-test-test-test-test-test-test-test\n\n") << QStringLiteral("test-test-test-test-test-test-test-test-test-\ntest-test-test-test\n\n");
+    QTest::newRow("wrap") << QStringLiteral("foosdfsdf sdsf sdfsdfsfs fsf sdfs df sfsdf dsf sdfsdf sf sf sfsdf sdsdf") << QStringLiteral(
+        "foosdfsdf sdsf sdfsdfsfs fsf sdfs df \nsfsdf dsf sdfsdf sf sf sfsdf sdsdf");
+    QTest::newRow("wrap-2") << QStringLiteral("test-test-test-test-test-test-test-test-test-test-test-test-test")
+                            << QStringLiteral("test-test-test-test-test-test-test-test-\ntest-test-test-test-test");
+    QTest::newRow("wrap-3") << QStringLiteral("test-test-test-test-test-test-test-test-test-test-test-test-test\n\n") << QStringLiteral(
+        "test-test-test-test-test-test-test-test-\ntest-test-test-test-test\n\n");
 }
 
 void RichTextComposerTest::testWrappedPlainText()
