@@ -50,7 +50,7 @@ public:
      *
      * @param te The text edit object to handle lists in.
      */
-    NestedListHelper(QTextEdit *te);
+    explicit NestedListHelper(QTextEdit *te);
 
     /**
      *
@@ -131,7 +131,7 @@ private:
     void reformatList(QTextBlock block);
     void reformatList();
 
-    QTextEdit *textEdit;
+    QTextEdit *textEdit = nullptr;
 
     int listBottomMargin;
     int listTopMargin;
