@@ -24,10 +24,8 @@
 #include "richtextcomposeremailquotehighlighter.h"
 #include "nestedlisthelper_p.h"
 #include "richtextexternalcomposer.h"
-#include <KLocalizedString>
 #include <QTextBlock>
 #include <QTextLayout>
-#include <QApplication>
 #include <QClipboard>
 
 #include "richtextcomposeremailquotedecorator.h"
@@ -38,7 +36,6 @@
 #include <QAction>
 #include <QFileInfo>
 #include <QMimeData>
-#include <QDebug>
 
 using namespace KPIMTextEdit;
 
@@ -59,11 +56,11 @@ public:
     }
 
     QString quotePrefix;
-    RichTextComposerControler *composerControler;
-    RichTextComposerActions *richTextComposerActions;
-    KPIMTextEdit::RichTextExternalComposer *externalComposer;
-    RichTextComposer *q;
-    bool forcePlainTextMarkup;
+    RichTextComposerControler *composerControler = nullptr;
+    RichTextComposerActions *richTextComposerActions = nullptr;
+    KPIMTextEdit::RichTextExternalComposer *externalComposer = nullptr;
+    RichTextComposer *q = nullptr;
+    bool forcePlainTextMarkup = false;
     RichTextComposer::Mode mode;
 };
 
