@@ -36,96 +36,96 @@ class Q_DECL_HIDDEN RichTextComposerActions::RichTextComposerActionsPrivate
 {
 public:
     RichTextComposerActionsPrivate(KPIMTextEdit::RichTextComposerControler *controler)
-        : composerControler(controler),
-          action_align_left(nullptr),
-          action_align_right(nullptr),
-          action_align_center(nullptr),
-          action_align_justify(nullptr),
-          action_direction_ltr(nullptr),
-          action_direction_rtl(nullptr),
-          action_text_superscript(nullptr),
-          action_text_subscript(nullptr),
-          action_text_bold(nullptr),
-          action_text_italic(nullptr),
-          action_text_underline(nullptr),
-          action_text_strikeout(nullptr),
-          action_font_family(nullptr),
-          action_font_size(nullptr),
-          action_insert_horizontal_rule(nullptr),
-          action_text_foreground_color(nullptr),
-          action_text_background_color(nullptr),
-          action_manage_link(nullptr),
-          action_list_indent(nullptr),
-          action_list_dedent(nullptr),
-          action_list_style(nullptr),
-          action_paste_quotation(nullptr),
-          action_add_quote_chars(nullptr),
-          action_remove_quote_chars(nullptr),
-          action_paste_without_formatting(nullptr),
-          action_add_image(nullptr),
-          action_add_emoticon(nullptr),
-          action_insert_html(nullptr),
-          action_add_table(nullptr),
-          action_delete_line(nullptr),
-          action_format_reset(nullptr),
-          action_format_painter(nullptr),
-          richTextEnabled(false)
+        : composerControler(controler)
+        , action_align_left(nullptr)
+        , action_align_right(nullptr)
+        , action_align_center(nullptr)
+        , action_align_justify(nullptr)
+        , action_direction_ltr(nullptr)
+        , action_direction_rtl(nullptr)
+        , action_text_superscript(nullptr)
+        , action_text_subscript(nullptr)
+        , action_text_bold(nullptr)
+        , action_text_italic(nullptr)
+        , action_text_underline(nullptr)
+        , action_text_strikeout(nullptr)
+        , action_font_family(nullptr)
+        , action_font_size(nullptr)
+        , action_insert_horizontal_rule(nullptr)
+        , action_text_foreground_color(nullptr)
+        , action_text_background_color(nullptr)
+        , action_manage_link(nullptr)
+        , action_list_indent(nullptr)
+        , action_list_dedent(nullptr)
+        , action_list_style(nullptr)
+        , action_paste_quotation(nullptr)
+        , action_add_quote_chars(nullptr)
+        , action_remove_quote_chars(nullptr)
+        , action_paste_without_formatting(nullptr)
+        , action_add_image(nullptr)
+        , action_add_emoticon(nullptr)
+        , action_insert_html(nullptr)
+        , action_add_table(nullptr)
+        , action_delete_line(nullptr)
+        , action_format_reset(nullptr)
+        , action_format_painter(nullptr)
+        , richTextEnabled(false)
     {
     }
+
     QList<QAction *> richTextActionList;
 
-    KPIMTextEdit::RichTextComposerControler *composerControler;
-    KToggleAction *action_align_left;
-    KToggleAction *action_align_right;
-    KToggleAction *action_align_center;
-    KToggleAction *action_align_justify;
+    KPIMTextEdit::RichTextComposerControler *composerControler = nullptr;
+    KToggleAction *action_align_left = nullptr;
+    KToggleAction *action_align_right = nullptr;
+    KToggleAction *action_align_center = nullptr;
+    KToggleAction *action_align_justify = nullptr;
 
-    KToggleAction *action_direction_ltr;
-    KToggleAction *action_direction_rtl;
+    KToggleAction *action_direction_ltr = nullptr;
+    KToggleAction *action_direction_rtl = nullptr;
 
-    KToggleAction *action_text_superscript;
-    KToggleAction *action_text_subscript;
+    KToggleAction *action_text_superscript = nullptr;
+    KToggleAction *action_text_subscript = nullptr;
 
-    KToggleAction *action_text_bold;
-    KToggleAction *action_text_italic;
-    KToggleAction *action_text_underline;
-    KToggleAction *action_text_strikeout;
+    KToggleAction *action_text_bold = nullptr;
+    KToggleAction *action_text_italic = nullptr;
+    KToggleAction *action_text_underline = nullptr;
+    KToggleAction *action_text_strikeout = nullptr;
 
-    KFontAction *action_font_family;
-    KFontSizeAction *action_font_size;
+    KFontAction *action_font_family = nullptr;
+    KFontSizeAction *action_font_size = nullptr;
 
-    QAction *action_insert_horizontal_rule;
-    QAction *action_text_foreground_color;
-    QAction *action_text_background_color;
-    QAction *action_manage_link;
+    QAction *action_insert_horizontal_rule = nullptr;
+    QAction *action_text_foreground_color = nullptr;
+    QAction *action_text_background_color = nullptr;
+    QAction *action_manage_link = nullptr;
 
-    QAction *action_list_indent;
-    QAction *action_list_dedent;
+    QAction *action_list_indent = nullptr;
+    QAction *action_list_dedent = nullptr;
 
-    KSelectAction *action_list_style;
+    KSelectAction *action_list_style = nullptr;
 
-    QAction *action_paste_quotation;
-    QAction *action_add_quote_chars;
-    QAction *action_remove_quote_chars;
-    QAction *action_paste_without_formatting;
+    QAction *action_paste_quotation = nullptr;
+    QAction *action_add_quote_chars = nullptr;
+    QAction *action_remove_quote_chars = nullptr;
+    QAction *action_paste_without_formatting = nullptr;
 
-    QAction *action_add_image;
-    QAction *action_add_emoticon;
-    QAction *action_insert_html;
-    KPIMTextEdit::TableActionMenu *action_add_table;
-    QAction *action_delete_line;
-    QAction *action_format_reset;
+    QAction *action_add_image = nullptr;
+    KPIMTextEdit::EmoticonTextEditAction *action_add_emoticon = nullptr;
+    QAction *action_insert_html = nullptr;
+    KPIMTextEdit::TableActionMenu *action_add_table = nullptr;
+    QAction *action_delete_line = nullptr;
+    QAction *action_format_reset = nullptr;
 
-    KToggleAction *action_format_painter;
+    KToggleAction *action_format_painter = nullptr;
 
-    bool richTextEnabled;
+    bool richTextEnabled = false;
 };
 
 RichTextComposerActions::RichTextComposerActions(KPIMTextEdit::RichTextComposerControler *controler, QObject *parent)
-    : QObject(parent),
-      d(new RichTextComposerActions::RichTextComposerActionsPrivate(controler))
+    : QObject(parent)
+    , d(new RichTextComposerActions::RichTextComposerActionsPrivate(controler))
 {
-
 }
 
 RichTextComposerActions::~RichTextComposerActions()
@@ -147,7 +147,7 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
 {
     //Alignment
     d->action_align_left = new KToggleAction(QIcon::fromTheme(QStringLiteral("format-justify-left")),
-            i18nc("@action", "Align &Left"), this);
+                                             i18nc("@action", "Align &Left"), this);
     d->action_align_left->setIconText(i18nc("@label left justify", "Left"));
     d->richTextActionList.append((d->action_align_left));
     d->action_align_left->setObjectName(QStringLiteral("format_align_left"));
@@ -158,7 +158,7 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
     }
 
     d->action_align_center = new KToggleAction(QIcon::fromTheme(QStringLiteral("format-justify-center")),
-            i18nc("@action", "Align &Center"), this);
+                                               i18nc("@action", "Align &Center"), this);
     d->action_align_center->setIconText(i18nc("@label center justify", "Center"));
     d->richTextActionList.append((d->action_align_center));
     d->action_align_center->setObjectName(QStringLiteral("format_align_center"));
@@ -169,7 +169,7 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
     }
 
     d->action_align_right = new KToggleAction(QIcon::fromTheme(QStringLiteral("format-justify-right")),
-            i18nc("@action", "Align &Right"), this);
+                                              i18nc("@action", "Align &Right"), this);
     d->action_align_right->setIconText(i18nc("@label right justify", "Right"));
     d->richTextActionList.append((d->action_align_right));
     d->action_align_right->setObjectName(QStringLiteral("format_align_right"));
@@ -180,7 +180,7 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
     }
 
     d->action_align_justify = new KToggleAction(QIcon::fromTheme(QStringLiteral("format-justify-fill")),
-            i18nc("@action", "&Justify"), this);
+                                                i18nc("@action", "&Justify"), this);
     d->action_align_justify->setIconText(i18nc("@label justify fill", "Justify"));
     d->richTextActionList.append((d->action_align_justify));
     d->action_align_justify->setObjectName(QStringLiteral("format_align_justify"));
@@ -198,7 +198,7 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
 
     //Align text
     d->action_direction_ltr = new KToggleAction(QIcon::fromTheme(QStringLiteral("format-text-direction-ltr")),
-            i18nc("@action", "Left-to-Right"), this);
+                                                i18nc("@action", "Left-to-Right"), this);
     d->action_direction_ltr->setIconText(i18nc("@label left-to-right", "Left-to-Right"));
     d->richTextActionList.append(d->action_direction_ltr);
     d->action_direction_ltr->setObjectName(QStringLiteral("direction_ltr"));
@@ -209,7 +209,7 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
     }
 
     d->action_direction_rtl = new KToggleAction(QIcon::fromTheme(QStringLiteral("format-text-direction-rtl")),
-            i18nc("@action", "Right-to-Left"), this);
+                                                i18nc("@action", "Right-to-Left"), this);
     d->action_direction_rtl->setIconText(i18nc("@label right-to-left", "Right-to-Left"));
     d->richTextActionList.append(d->action_direction_rtl);
     d->action_direction_rtl->setObjectName(QStringLiteral("direction_rtl"));
@@ -225,7 +225,7 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
 
     // Sub/Super script
     d->action_text_subscript = new KToggleAction(QIcon::fromTheme(QStringLiteral("format-text-subscript")),
-            i18nc("@action", "Subscript"), this);
+                                                 i18nc("@action", "Subscript"), this);
     d->richTextActionList.append((d->action_text_subscript));
     d->action_text_subscript->setObjectName(QStringLiteral("format_text_subscript"));
     connect(d->action_text_subscript, &KToggleAction::triggered,
@@ -235,7 +235,7 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
     }
 
     d->action_text_superscript = new KToggleAction(QIcon::fromTheme(QStringLiteral("format-text-superscript")),
-            i18nc("@action", "Superscript"), this);
+                                                   i18nc("@action", "Superscript"), this);
     d->richTextActionList.append((d->action_text_superscript));
     d->action_text_superscript->setObjectName(QStringLiteral("format_text_superscript"));
     connect(d->action_text_superscript, &KToggleAction::triggered,
@@ -258,7 +258,7 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
     connect(d->action_text_bold, &KToggleAction::triggered, d->composerControler, &RichTextComposerControler::setTextBold);
 
     d->action_text_italic = new KToggleAction(QIcon::fromTheme(QStringLiteral("format-text-italic")),
-            i18nc("@action italicize selected text", "&Italic"), this);
+                                              i18nc("@action italicize selected text", "&Italic"), this);
     QFont italic;
     italic.setItalic(true);
     d->action_text_italic->setFont(italic);
@@ -271,7 +271,7 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
     connect(d->action_text_italic, &KToggleAction::triggered, d->composerControler, &RichTextComposerControler::setTextItalic);
 
     d->action_text_underline = new KToggleAction(QIcon::fromTheme(QStringLiteral("format-text-underline")),
-            i18nc("@action underline selected text", "&Underline"), this);
+                                                 i18nc("@action underline selected text", "&Underline"), this);
     QFont underline;
     underline.setUnderline(true);
     d->action_text_underline->setFont(underline);
@@ -284,7 +284,7 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
     connect(d->action_text_underline, &KToggleAction::triggered, d->composerControler, &RichTextComposerControler::setTextUnderline);
 
     d->action_text_strikeout = new KToggleAction(QIcon::fromTheme(QStringLiteral("format-text-strikethrough")),
-            i18nc("@action", "&Strike Out"), this);
+                                                 i18nc("@action", "&Strike Out"), this);
     QFont strikeout;
     strikeout.setStrikeOut(true);
     d->action_text_strikeout->setFont(strikeout);
@@ -305,7 +305,8 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
     if (ac) {
         ac->addAction(QStringLiteral("format_font_family"), d->action_font_family);
     }
-    connect(d->action_font_family, SIGNAL(triggered(QString)), d->composerControler, SLOT(setFontFamily(QString)));
+    connect(d->action_font_family, QOverload<const QString &>::of(&KFontAction::triggered),
+            d->composerControler, &RichTextComposerControler::setFontFamily);
 
     //Font Size
     d->action_font_size = new KFontSizeAction(i18nc("@action", "Font &Size"), this);
@@ -317,7 +318,7 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
     connect(d->action_font_size, &KFontSizeAction::fontSizeChanged, d->composerControler, &RichTextComposerControler::setFontSize);
 
     d->action_insert_horizontal_rule = new QAction(QIcon::fromTheme(QStringLiteral("insert-horizontal-rule")),
-            i18nc("@action", "Insert Rule Line"), this);
+                                                   i18nc("@action", "Insert Rule Line"), this);
     d->richTextActionList.append((d->action_insert_horizontal_rule));
     d->action_insert_horizontal_rule->setObjectName(QStringLiteral("insert_horizontal_rule"));
     if (ac) {
@@ -328,7 +329,7 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
 
     //Foreground Color
     d->action_text_foreground_color = new QAction(QIcon::fromTheme(QStringLiteral("format-stroke-color")),
-            i18nc("@action", "Text &Color..."), this);
+                                                  i18nc("@action", "Text &Color..."), this);
     d->action_text_foreground_color->setIconText(i18nc("@label stroke color", "Color"));
     d->richTextActionList.append((d->action_text_foreground_color));
     d->action_text_foreground_color->setObjectName(QStringLiteral("format_text_foreground_color"));
@@ -338,7 +339,7 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
     connect(d->action_text_foreground_color, &QAction::triggered, d->composerControler, &RichTextComposerControler::setChangeTextForegroundColor);
     //Background Color
     d->action_text_background_color = new QAction(QIcon::fromTheme(QStringLiteral("format-fill-color")),
-            i18nc("@action", "Text &Highlight..."), this);
+                                                  i18nc("@action", "Text &Highlight..."), this);
     d->richTextActionList.append((d->action_text_background_color));
     if (ac) {
         ac->addAction(QStringLiteral("format_text_background_color"), d->action_text_background_color);
@@ -380,17 +381,17 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
             this, &RichTextComposerActions::slotUpdateMiscActions);
 
     d->action_list_style = new KSelectAction(QIcon::fromTheme(QStringLiteral("format-list-unordered")),
-            i18nc("@title:menu", "List Style"), this);
+                                             i18nc("@title:menu", "List Style"), this);
     QStringList listStyles;
-    listStyles      << i18nc("@item:inmenu no list style", "None")
-                    << i18nc("@item:inmenu disc list style", "Disc")
-                    << i18nc("@item:inmenu circle list style", "Circle")
-                    << i18nc("@item:inmenu square list style", "Square")
-                    << i18nc("@item:inmenu numbered lists", "123")
-                    << i18nc("@item:inmenu lowercase abc lists", "abc")
-                    << i18nc("@item:inmenu uppercase abc lists", "ABC")
-                    << i18nc("@item:inmenu lower case roman numerals", "i ii iii")
-                    << i18nc("@item:inmenu upper case roman numerals", "I II III");
+    listStyles << i18nc("@item:inmenu no list style", "None")
+               << i18nc("@item:inmenu disc list style", "Disc")
+               << i18nc("@item:inmenu circle list style", "Circle")
+               << i18nc("@item:inmenu square list style", "Square")
+               << i18nc("@item:inmenu numbered lists", "123")
+               << i18nc("@item:inmenu lowercase abc lists", "abc")
+               << i18nc("@item:inmenu uppercase abc lists", "ABC")
+               << i18nc("@item:inmenu lower case roman numerals", "i ii iii")
+               << i18nc("@item:inmenu upper case roman numerals", "I II III");
 
     d->action_list_style->setItems(listStyles);
     d->action_list_style->setCurrentItem(0);
@@ -399,11 +400,10 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
     if (ac) {
         ac->addAction(QStringLiteral("format_list_style"), d->action_list_style);
     }
-    connect(d->action_list_style, SIGNAL(triggered(int)),
-            this, SLOT(setListStyle(int)));
-    connect(d->action_list_style, SIGNAL(triggered()),
-            this, SLOT(slotUpdateMiscActions()));
-
+    connect(d->action_list_style, QOverload<int>::of(&KSelectAction::triggered),
+            this, &RichTextComposerActions::setListStyle);
+    connect(d->action_list_style, QOverload<bool>::of(&QAction::triggered),
+                this, &RichTextComposerActions::slotUpdateMiscActions);
     d->action_paste_quotation = new QAction(i18n("Pa&ste as Quotation"), this);
     d->action_paste_quotation->setObjectName(QStringLiteral("paste_quoted"));
     if (ac) {
@@ -448,7 +448,7 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
     if (ac) {
         ac->addAction(QStringLiteral("add_emoticon"), d->action_add_emoticon);
     }
-    connect(d->action_add_emoticon, SIGNAL(emoticonActivated(QString)), d->composerControler, SLOT(slotAddEmoticon(QString)));
+    connect(d->action_add_emoticon, &EmoticonTextEditAction::emoticonActivated, d->composerControler, &RichTextComposerControler::slotAddEmoticon);
     d->richTextActionList.append(d->action_add_emoticon);
 
     d->action_insert_html = new QAction(i18n("Insert HTML"), this);
@@ -480,8 +480,8 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
     connect(d->action_delete_line, &QAction::triggered, d->composerControler, &RichTextComposerControler::slotDeleteLine);
     d->richTextActionList.append(d->action_delete_line);
 
-    d->action_format_reset =
-        new QAction(QIcon::fromTheme(QStringLiteral("draw-eraser")), i18n("Reset Font Settings"), this);
+    d->action_format_reset
+        = new QAction(QIcon::fromTheme(QStringLiteral("draw-eraser")), i18n("Reset Font Settings"), this);
     d->action_format_reset->setIconText(i18n("Reset Font"));
     d->action_format_reset->setObjectName(QStringLiteral("format_reset"));
     connect(d->action_format_reset, &QAction::triggered, d->composerControler, &RichTextComposerControler::slotFormatReset);
@@ -491,7 +491,7 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
     d->richTextActionList.append(d->action_format_reset);
 
     d->action_format_painter = new KToggleAction(QIcon::fromTheme(QStringLiteral("draw-brush")),
-            i18nc("@action", "Format Painter"), this);
+                                                 i18nc("@action", "Format Painter"), this);
     d->richTextActionList.append(d->action_format_painter);
     d->action_format_painter->setObjectName(QStringLiteral("format_painter"));
     if (ac) {
@@ -528,7 +528,7 @@ void RichTextComposerActions::setListStyle(int _styleindex)
 
 void RichTextComposerActions::setActionsEnabled(bool enabled)
 {
-    Q_FOREACH (QAction *action, d->richTextActionList) {
+    for (QAction *action : qAsConst(d->richTextActionList)) {
         action->setEnabled(enabled);
     }
     d->richTextEnabled = enabled;
