@@ -39,7 +39,6 @@
 #include <QTextDocumentFragment>
 #include "textutils.h"
 #include "insertimagedialog.h"
-#include <QDebug>
 
 using namespace KPIMTextEdit;
 
@@ -78,10 +77,10 @@ public:
     QColor mLinkColor;
     QTextCharFormat painterFormat;
     bool painterActive;
-    NestedListHelper *nestedListHelper;
-    RichTextComposer *richtextComposer;
-    RichTextComposerImages *richTextImages;
-    RichTextComposerControler *q;
+    NestedListHelper *nestedListHelper = nullptr;
+    RichTextComposer *richtextComposer = nullptr;
+    RichTextComposerImages *richTextImages = nullptr;
+    RichTextComposerControler *q = nullptr;
 };
 
 void RichTextComposerControler::RichTextComposerControlerPrivate::selectLinkText(QTextCursor *cursor) const
@@ -416,7 +415,7 @@ void RichTextComposerControler::selectLinkText() const
 void RichTextComposerControler::manageLink()
 {
     selectLinkText();
-    KLinkDialog *linkDialog = new KLinkDialog(richTextComposer());
+    QPointer<KLinkDialog> linkDialog = new KLinkDialog(richTextComposer());
     linkDialog->setLinkText(currentLinkText());
     linkDialog->setLinkUrl(currentLinkUrl());
 
@@ -722,7 +721,7 @@ void RichTextComposerControler::slotInsertHtml()
 void RichTextComposerControler::slotAddImage()
 {
     QPointer<KPIMTextEdit::InsertImageDialog> dlg = new KPIMTextEdit::InsertImageDialog(richTextComposer());
-    if (dlg->exec() == QDialog::Accepted && dlg) {
+    if (dlg->exec() == QDialog::Accepted) {
         const QUrl url = dlg->imageUrl();
         int imageWidth = -1;
         int imageHeight = -1;
