@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,9 +23,7 @@
 #include <QObject>
 #include "richtextcomposer.h"
 #include "kpimtextedit_export.h"
-class QTextCursor;
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class RichTextComposer;
 class NestedListHelper;
 class RichTextComposerImages;
