@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,8 +23,7 @@
 #include <sonnet/spellcheckdecorator.h>
 #include "kpimtextedit_export.h"
 
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class RichTextComposer;
 class KPIMTEXTEDIT_EXPORT RichTextComposerEmailQuoteDecorator : public Sonnet::SpellCheckDecorator
 {
@@ -33,7 +32,7 @@ public:
     ~RichTextComposerEmailQuoteDecorator();
 
 protected:
-    bool isSpellCheckingEnabledForBlock(const QString &blockText) const Q_DECL_OVERRIDE;
+    bool isSpellCheckingEnabledForBlock(const QString &blockText) const override;
 private:
     class RichTextComposerEmailQuoteDecoratorPrivate;
     RichTextComposerEmailQuoteDecoratorPrivate *const d;
