@@ -46,7 +46,7 @@ public:
      */
     QStringList mImageNames;
 
-    RichTextComposer *composer;
+    RichTextComposer *composer = nullptr;
 };
 
 RichTextComposerImages::RichTextComposerImages(RichTextComposer *composer, QObject *parent)
@@ -193,7 +193,7 @@ QList< QSharedPointer<EmbeddedImage> > RichTextComposerImages::embeddedImages()
         buffer.open(QIODevice::WriteOnly);
         normalImage->image.save(&buffer, "PNG");
 
-        qsrand(QDateTime::currentDateTimeUtc().toTime_t() + qHash(normalImage->name));
+        qsrand(QDateTime::currentDateTimeUtc().toSecsSinceEpoch() + qHash(normalImage->name));
         QSharedPointer<EmbeddedImage> embeddedImage(new EmbeddedImage());
         retImages.append(embeddedImage);
         embeddedImage->image = KCodecs::Codec::codecForName("base64")->encode(buffer.buffer());
