@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -19,6 +19,7 @@
 
 #include "richtextcomposer.h"
 #include "richtextexternalcomposer.h"
+#include "richtextexternalcomposer.h"
 
 #include <KProcess>
 #include <KMacroExpander>
@@ -33,25 +34,22 @@ class Q_DECL_HIDDEN RichTextExternalComposer::RichTextExternalComposerPrivate
 {
 public:
     RichTextExternalComposerPrivate(RichTextComposer *composer)
-        : externalEditorProcess(Q_NULLPTR),
-          extEditorTempFile(Q_NULLPTR),
-          richTextComposer(composer),
-          useExtEditor(false)
+        : richTextComposer(composer)
     {
-
     }
+
     void cannotStartProcess(const QString &commandLine);
     QString extEditorPath;
-    KProcess *externalEditorProcess;
-    QTemporaryFile *extEditorTempFile;
-    RichTextComposer *richTextComposer;
-    bool useExtEditor;
+    KProcess *externalEditorProcess = nullptr;
+    QTemporaryFile *extEditorTempFile = nullptr;
+    RichTextComposer *richTextComposer = nullptr;
+    bool useExtEditor = false;
 };
 
 RichTextExternalComposer::RichTextExternalComposer(RichTextComposer *composer, QObject *parent)
-    : QObject(parent), d(new RichTextExternalComposerPrivate(composer))
+    : QObject(parent)
+    , d(new RichTextExternalComposerPrivate(composer))
 {
-
 }
 
 RichTextExternalComposer::~RichTextExternalComposer()
@@ -82,7 +80,6 @@ QString RichTextExternalComposer::externalEditorPath() const
 void RichTextExternalComposer::startExternalEditor()
 {
     if (d->useExtEditor && !d->externalEditorProcess) {
-
         const QString commandLine = d->extEditorPath.trimmed();
         if (d->extEditorPath.isEmpty()) {
             setUseExternalEditor(false);
@@ -93,7 +90,7 @@ void RichTextExternalComposer::startExternalEditor()
         d->extEditorTempFile = new QTemporaryFile();
         if (!d->extEditorTempFile->open()) {
             delete d->extEditorTempFile;
-            d->extEditorTempFile = Q_NULLPTR;
+            d->extEditorTempFile = nullptr;
             setUseExternalEditor(false);
             return;
         }
@@ -127,8 +124,7 @@ void RichTextExternalComposer::startExternalEditor()
             (*d->externalEditorProcess) << d->extEditorTempFile->fileName();
         }
 
-        connect(d->externalEditorProcess, SIGNAL(finished(int,QProcess::ExitStatus)),
-                this, SLOT(slotEditorFinished(int,QProcess::ExitStatus)));
+        connect(d->externalEditorProcess, QOverload<int,QProcess::ExitStatus>::of(&KProcess::finished), this, &RichTextExternalComposer::slotEditorFinished);
         d->externalEditorProcess->start();
         if (!d->externalEditorProcess->waitForStarted()) {
             d->cannotStartProcess(commandLine);
@@ -174,15 +170,15 @@ bool RichTextExternalComposer::checkExternalEditorFinished()
     }
 
     int ret = KMessageBox::warningYesNoCancel(
-                  d->richTextComposer,
-                  xi18nc("@info",
-                         "The external editor is still running.<nl/>"
-                         "Do you want to stop the editor or keep it running?<nl/>"
-                         "<warning>Stopping the editor will cause all your "
-                         "unsaved changes to be lost.</warning>"),
-                  i18nc("@title:window", "External Editor Running"),
-                  KGuiItem(i18nc("@action:button", "Stop Editor")),
-                  KGuiItem(i18nc("@action:button", "Keep Editor Running")));
+        d->richTextComposer,
+        xi18nc("@info",
+               "The external editor is still running.<nl/>"
+               "Do you want to stop the editor or keep it running?<nl/>"
+               "<warning>Stopping the editor will cause all your "
+               "unsaved changes to be lost.</warning>"),
+        i18nc("@title:window", "External Editor Running"),
+        KGuiItem(i18nc("@action:button", "Stop Editor")),
+        KGuiItem(i18nc("@action:button", "Keep Editor Running")));
 
     switch (ret) {
     case KMessageBox::Yes:
@@ -192,7 +188,6 @@ bool RichTextExternalComposer::checkExternalEditorFinished()
         return true;
     default:
         return false;
-
     }
 }
 
@@ -201,9 +196,9 @@ void RichTextExternalComposer::killExternalEditor()
     if (d->externalEditorProcess) {
         d->externalEditorProcess->deleteLater();
     }
-    d->externalEditorProcess = Q_NULLPTR;
+    d->externalEditorProcess = nullptr;
     delete d->extEditorTempFile;
-    d->extEditorTempFile = Q_NULLPTR;
+    d->extEditorTempFile = nullptr;
 }
 
 bool RichTextExternalComposer::isInProgress() const
