@@ -37,8 +37,7 @@ public:
         : q(qq)
     {
         q->setWindowTitle(i18nc("@title:window", "Insert HTML"));
-        QVBoxLayout *lay = new QVBoxLayout;
-        q->setLayout(lay);
+        QVBoxLayout *lay = new QVBoxLayout(q);
         QLabel *label = new QLabel(i18n("Insert HTML tags and texts:"));
         lay->addWidget(label);
         editor = new InsertHtmlEditor;
@@ -51,7 +50,7 @@ public:
         label->setFont(font);
         label->setTextFormat(Qt::PlainText);
         lay->addWidget(label);
-        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, q);
         okButton = buttonBox->button(QDialogButtonBox::Ok);
         okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
         okButton->setText(i18nc("@action:button", "Insert"));
@@ -60,16 +59,15 @@ public:
         q->connect(buttonBox, &QDialogButtonBox::rejected, q, &QDialog::reject);
 
         lay->addWidget(buttonBox);
-        q->connect(editor, SIGNAL(textChanged()),
-                   q, SLOT(_k_slotTextChanged()));
+        q->connect(editor, &InsertHtmlEditor::textChanged, q, [this]() {_k_slotTextChanged(); });
         okButton->setEnabled(false);
         q->resize(640, 480);
     }
 
     void _k_slotTextChanged();
-    QPushButton *okButton;
-    InsertHtmlEditor *editor;
-    InsertHtmlDialog *q;
+    QPushButton *okButton = nullptr;
+    InsertHtmlEditor *editor = nullptr;
+    InsertHtmlDialog *q = nullptr;
 };
 
 void InsertHtmlDialogPrivate::_k_slotTextChanged()
