@@ -28,24 +28,20 @@
 #include <QVBoxLayout>
 #include <QPushButton>
 
-namespace KPIMTextEdit
-{
-
+namespace KPIMTextEdit {
 class InsertImageDialogPrivate
 {
 public:
     InsertImageDialogPrivate(InsertImageDialog *qq)
         : q(qq)
     {
-        QVBoxLayout *vbox = new QVBoxLayout;
-        q->setLayout(vbox);
+        QVBoxLayout *vbox = new QVBoxLayout(q);
         q->setWindowTitle(i18n("Insert Image"));
 
         imageWidget = new InsertImageWidget(q);
         vbox->addWidget(imageWidget);
-        q->connect(imageWidget, SIGNAL(enableButtonOk(bool)),
-                   q, SLOT(_k_slotEnabledButtonChanged(bool)));
-        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+        q->connect(imageWidget, &InsertImageWidget::enableButtonOk, q, [this](bool b) { _k_slotEnabledButtonChanged(b); });
+        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, q);
         okButton = buttonBox->button(QDialogButtonBox::Ok);
         okButton->setText(i18n("Insert"));
         okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -61,13 +57,14 @@ public:
         okButton->setEnabled(enabled);
     }
 
-    InsertImageWidget *imageWidget;
-    QPushButton *okButton;
-    InsertImageDialog *q;
+    InsertImageWidget *imageWidget = nullptr;
+    QPushButton *okButton = nullptr;
+    InsertImageDialog *q = nullptr;
 };
 
 InsertImageDialog::InsertImageDialog(QWidget *parent)
-    : QDialog(parent), d(new InsertImageDialogPrivate(this))
+    : QDialog(parent)
+    , d(new InsertImageDialogPrivate(this))
 {
 }
 
@@ -110,6 +107,5 @@ bool InsertImageDialog::keepOriginalSize() const
 {
     return d->imageWidget->keepOriginalSize();
 }
-
 }
 #include "moc_insertimagedialog.cpp"
