@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -27,9 +27,7 @@
 
 #include <QTextLength>
 
-namespace KPIMTextEdit
-{
-
+namespace KPIMTextEdit {
 class KPIMTEXTEDIT_EXPORT InsertTableDialog : public QDialog
 {
     Q_OBJECT
@@ -53,7 +51,6 @@ private:
     class InsertTableDialogPrivate;
     InsertTableDialogPrivate *const d;
 };
-
 }
 
 #endif // KPIMTEXTEDIT_INSERTTABLEDIALOG_H
