@@ -24,14 +24,13 @@
 #include <QPushButton>
 #include <QVBoxLayout>
 
-namespace KPIMTextEdit
-{
-
+namespace KPIMTextEdit {
 class SelectSpecialCharDialogPrivate
 {
 public:
     SelectSpecialCharDialogPrivate(SelectSpecialCharDialog *qq)
-        : mSelectButton(nullptr), q(qq)
+        : mSelectButton(nullptr)
+        , q(qq)
     {
         q->setWindowTitle(i18n("Select Special Characters"));
 
@@ -42,7 +41,7 @@ public:
                    q, &SelectSpecialCharDialog::charSelected);
         lay->addWidget(mCharSelect);
 
-        mButtonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+        mButtonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, q);
         QPushButton *okButton = mButtonBox->button(QDialogButtonBox::Ok);
         okButton->setText(i18n("Insert"));
         okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -50,24 +49,22 @@ public:
         q->connect(mButtonBox, &QDialogButtonBox::accepted, q, &QDialog::accept);
         q->connect(mButtonBox, &QDialogButtonBox::rejected, q, &QDialog::reject);
 
-        q->connect(okButton, SIGNAL(clicked()),
-                   q, SLOT(_k_slotInsertChar()));
+        q->connect(okButton, &QPushButton::clicked, q, [this]() { _k_slotInsertChar(); });
     }
 
     void addSelectButton()
     {
         mSelectButton = new QPushButton(i18n("Select"));
         mButtonBox->addButton(mSelectButton, QDialogButtonBox::ActionRole);
-        q->connect(mSelectButton, SIGNAL(clicked()),
-                   q, SLOT(_k_slotInsertChar()));
+        q->connect(mSelectButton, &QPushButton::clicked, q, [this]() { _k_slotInsertChar(); });
     }
 
     void _k_slotInsertChar();
 
-    KCharSelect *mCharSelect;
-    QDialogButtonBox *mButtonBox;
-    QPushButton *mSelectButton;
-    SelectSpecialCharDialog *q;
+    KCharSelect *mCharSelect = nullptr;
+    QDialogButtonBox *mButtonBox = nullptr;
+    QPushButton *mSelectButton = nullptr;
+    SelectSpecialCharDialog *q = nullptr;
 };
 
 void SelectSpecialCharDialogPrivate::_k_slotInsertChar()
@@ -76,7 +73,8 @@ void SelectSpecialCharDialogPrivate::_k_slotInsertChar()
 }
 
 SelectSpecialCharDialog::SelectSpecialCharDialog(QWidget *parent)
-    : QDialog(parent), d(new SelectSpecialCharDialogPrivate(this))
+    : QDialog(parent)
+    , d(new SelectSpecialCharDialogPrivate(this))
 {
 }
 
@@ -113,7 +111,6 @@ void SelectSpecialCharDialog::setOkButtonText(const QString &text)
 {
     d->mButtonBox->button(QDialogButtonBox::Ok)->setText(text);
 }
-
 }
 
 #include "moc_selectspecialchardialog.cpp"
