@@ -21,7 +21,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #define SLIDECONTAINER_H
 
 // Qt
-#include <QWeakPointer>
 #include <QFrame>
 #include <QPointer>
 
@@ -85,7 +84,7 @@ private Q_SLOTS:
 
 private:
     QPointer<QWidget> mContent;
-    QWeakPointer<QPropertyAnimation> mAnim;
+    QPointer<QPropertyAnimation> mAnim;
     bool mSlidingOut;
 
     void adjustContentGeometry();
