@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -22,7 +22,6 @@
 #include "inserttabledialog.h"
 #include "tableformatdialog.h"
 #include "tablecellformatdialog.h"
-#include <QDebug>
 
 #include <QAction>
 #include <QIcon>
@@ -32,14 +31,14 @@
 #include <QPointer>
 #include <QTextEdit>
 
-namespace KPIMTextEdit
-{
-
+namespace KPIMTextEdit {
 class TableActionMenuPrivate
 {
 public:
     TableActionMenuPrivate(QTextEdit *edit, TableActionMenu *qq)
-        : textEdit(edit), q(qq), richTextMode(false)
+        : textEdit(edit)
+        , q(qq)
+        , richTextMode(false)
     {
     }
 
@@ -63,32 +62,32 @@ public:
     void _k_slotSplitCell();
     void _k_updateActions(bool forceUpdate = false);
 
-    QAction *actionInsertTable;
+    QAction *actionInsertTable = nullptr;
 
-    QAction *actionInsertRowBelow;
-    QAction *actionInsertRowAbove;
+    QAction *actionInsertRowBelow = nullptr;
+    QAction *actionInsertRowAbove = nullptr;
 
-    QAction *actionInsertColumnBefore;
-    QAction *actionInsertColumnAfter;
+    QAction *actionInsertColumnBefore = nullptr;
+    QAction *actionInsertColumnAfter = nullptr;
 
-    QAction *actionRemoveRowBelow;
-    QAction *actionRemoveRowAbove;
+    QAction *actionRemoveRowBelow = nullptr;
+    QAction *actionRemoveRowAbove = nullptr;
 
-    QAction *actionRemoveColumnBefore;
-    QAction *actionRemoveColumnAfter;
+    QAction *actionRemoveColumnBefore = nullptr;
+    QAction *actionRemoveColumnAfter = nullptr;
 
-    QAction *actionMergeCell;
-    QAction *actionMergeSelectedCells;
-    QAction *actionSplitCell;
+    QAction *actionMergeCell = nullptr;
+    QAction *actionMergeSelectedCells = nullptr;
+    QAction *actionSplitCell = nullptr;
 
-    QAction *actionTableFormat;
-    QAction *actionTableCellFormat;
+    QAction *actionTableFormat = nullptr;
+    QAction *actionTableCellFormat = nullptr;
 
-    QAction *actionRemoveCellContents;
+    QAction *actionRemoveCellContents = nullptr;
 
-    QTextEdit *textEdit;
-    TableActionMenu *q;
-    bool richTextMode;
+    QTextEdit *textEdit = nullptr;
+    TableActionMenu *q = nullptr;
+    bool richTextMode = false;
 };
 
 void TableActionMenuPrivate::_k_slotRemoveCellContents()
@@ -288,8 +287,8 @@ void TableActionMenuPrivate::_k_slotTableFormat()
 
             if (dialog->exec()) {
                 const int newNumberOfColumns(dialog->columns());
-                if ((newNumberOfColumns != numberOfColumn) ||
-                        (dialog->rows() != numberOfRow)) {
+                if ((newNumberOfColumns != numberOfColumn)
+                    || (dialog->rows() != numberOfRow)) {
                     table->resize(dialog->rows(), newNumberOfColumns);
                 }
                 tableFormat.setBorder(dialog->border());
@@ -371,7 +370,7 @@ void TableActionMenuPrivate::_k_updateActions(bool forceUpdate)
 {
     if ((richTextMode) || forceUpdate) {
         QTextTable *table = textEdit->textCursor().currentTable();
-        const bool isTable = (table != 0);
+        const bool isTable = (table != nullptr);
         actionInsertRowBelow->setEnabled(isTable);
         actionInsertRowAbove->setEnabled(isTable);
 
@@ -392,15 +391,15 @@ void TableActionMenuPrivate::_k_updateActions(bool forceUpdate)
             int firstColumn = -1;
             int numColumns = -1;
             textEdit->textCursor().selectedTableCells(&firstRow, &numRows, &firstColumn, &numColumns);
-            const bool hasSelectedTableCell =
-                (firstRow != -1) && (numRows != -1) &&
-                (firstColumn != -1) && (numColumns != -1);
+            const bool hasSelectedTableCell
+                = (firstRow != -1) && (numRows != -1)
+                  && (firstColumn != -1) && (numColumns != -1);
             if (cell.column() > table->columns() - 2) {
                 actionMergeCell->setEnabled(false);
             } else {
                 actionMergeCell->setEnabled(true);
             }
-            if (cell.columnSpan() > 1 ||  cell.rowSpan() > 1) {
+            if (cell.columnSpan() > 1 || cell.rowSpan() > 1) {
                 actionSplitCell->setEnabled(true);
             } else {
                 actionSplitCell->setEnabled(false);
@@ -419,7 +418,8 @@ void TableActionMenuPrivate::_k_updateActions(bool forceUpdate)
 }
 
 TableActionMenu::TableActionMenu(QTextEdit *textEdit)
-    : KActionMenu(textEdit), d(new TableActionMenuPrivate(textEdit, this))
+    : KActionMenu(textEdit)
+    , d(new TableActionMenuPrivate(textEdit, this))
 {
     KActionMenu *insertMenu = new KActionMenu(i18n("Insert"), this);
     addAction(insertMenu);
@@ -427,43 +427,38 @@ TableActionMenu::TableActionMenu(QTextEdit *textEdit)
     d->actionInsertTable = new QAction(QIcon::fromTheme(QStringLiteral("insert-table")), i18n("Table..."), this);
     d->actionInsertTable->setObjectName(QStringLiteral("insert_new_table"));
     insertMenu->addAction(d->actionInsertTable);
-    connect(d->actionInsertTable, SIGNAL(triggered(bool)),
-            SLOT(_k_slotInsertTable()));
+    connect(d->actionInsertTable, &QAction::triggered, this, [this]() {d->_k_slotInsertTable();});
 
     insertMenu->addSeparator();
-    d->actionInsertRowBelow =
-        new QAction(QIcon::fromTheme(QStringLiteral("edit-table-insert-row-below")),
-                    i18n("Row Below"), this);
+    d->actionInsertRowBelow
+        = new QAction(QIcon::fromTheme(QStringLiteral("edit-table-insert-row-below")),
+                      i18n("Row Below"), this);
     insertMenu->addAction(d->actionInsertRowBelow);
     d->actionInsertRowBelow->setObjectName(QStringLiteral("insert_row_below"));
-    connect(d->actionInsertRowBelow, SIGNAL(triggered(bool)),
-            SLOT(_k_slotInsertRowBelow()));
+    connect(d->actionInsertRowBelow, &QAction::triggered, this, [this]() {d->_k_slotInsertRowBelow();});
 
-    d->actionInsertRowAbove =
-        new QAction(QIcon::fromTheme(QStringLiteral("edit-table-insert-row-above")),
-                    i18n("Row Above"), this);
+    d->actionInsertRowAbove
+        = new QAction(QIcon::fromTheme(QStringLiteral("edit-table-insert-row-above")),
+                      i18n("Row Above"), this);
     insertMenu->addAction(d->actionInsertRowAbove);
     d->actionInsertRowAbove->setObjectName(QStringLiteral("insert_row_above"));
-    connect(d->actionInsertRowAbove, SIGNAL(triggered(bool)),
-            SLOT(_k_slotInsertRowAbove()));
+    connect(d->actionInsertRowAbove, &QAction::triggered, this, [this]() {d->_k_slotInsertRowAbove();});
 
     insertMenu->addSeparator();
-    d->actionInsertColumnBefore =
-        new QAction(QIcon::fromTheme(QStringLiteral("edit-table-insert-column-left")),
-                    i18n("Column Before"), this);
+    d->actionInsertColumnBefore
+        = new QAction(QIcon::fromTheme(QStringLiteral("edit-table-insert-column-left")),
+                      i18n("Column Before"), this);
     insertMenu->addAction(d->actionInsertColumnBefore);
     d->actionInsertColumnBefore->setObjectName(QStringLiteral("insert_column_before"));
 
-    connect(d->actionInsertColumnBefore, SIGNAL(triggered(bool)),
-            SLOT(_k_slotInsertColumnBefore()));
+    connect(d->actionInsertColumnBefore, &QAction::triggered, this, [this]() {d->_k_slotInsertColumnBefore();});
 
-    d->actionInsertColumnAfter =
-        new QAction(QIcon::fromTheme(QStringLiteral("edit-table-insert-column-right")),
-                    i18n("Column After"), this);
+    d->actionInsertColumnAfter
+        = new QAction(QIcon::fromTheme(QStringLiteral("edit-table-insert-column-right")),
+                      i18n("Column After"), this);
     insertMenu->addAction(d->actionInsertColumnAfter);
     d->actionInsertColumnAfter->setObjectName(QStringLiteral("insert_column_after"));
-    connect(d->actionInsertColumnAfter, SIGNAL(triggered(bool)),
-            SLOT(_k_slotInsertColumnAfter()));
+    connect(d->actionInsertColumnAfter, &QAction::triggered, this, [this]() {d->_k_slotInsertColumnAfter();});
 
     KActionMenu *removeMenu = new KActionMenu(i18n("Delete"), this);
     addAction(removeMenu);
@@ -471,76 +466,65 @@ TableActionMenu::TableActionMenu(QTextEdit *textEdit)
     d->actionRemoveRowBelow = new QAction(i18n("Row Below"), this);
     removeMenu->addAction(d->actionRemoveRowBelow);
     d->actionRemoveRowBelow->setObjectName(QStringLiteral("remove_row_below"));
-    connect(d->actionRemoveRowBelow, SIGNAL(triggered(bool)),
-            SLOT(_k_slotRemoveRowBelow()));
+    connect(d->actionRemoveRowBelow, &QAction::triggered, this, [this]() {d->_k_slotRemoveRowBelow();});
 
     d->actionRemoveRowAbove = new QAction(i18n("Row Above"), this);
     removeMenu->addAction(d->actionRemoveRowAbove);
     d->actionRemoveRowAbove->setObjectName(QStringLiteral("remove_row_above"));
-    connect(d->actionRemoveRowAbove, SIGNAL(triggered(bool)),
-            SLOT(_k_slotRemoveRowAbove()));
+    connect(d->actionRemoveRowAbove, &QAction::triggered, this, [this]() {d->_k_slotRemoveRowAbove();});
 
     removeMenu->addSeparator();
     d->actionRemoveColumnBefore = new QAction(i18n("Column Before"), this);
     removeMenu->addAction(d->actionRemoveColumnBefore);
     d->actionRemoveColumnBefore->setObjectName(QStringLiteral("remove_column_before"));
 
-    connect(d->actionRemoveColumnBefore, SIGNAL(triggered(bool)),
-            SLOT(_k_slotRemoveColumnBefore()));
+    connect(d->actionRemoveColumnBefore, &QAction::triggered, this, [this]() {d->_k_slotRemoveColumnBefore();});
 
     d->actionRemoveColumnAfter = new QAction(i18n("Column After"), this);
     removeMenu->addAction(d->actionRemoveColumnAfter);
     d->actionRemoveColumnAfter->setObjectName(QStringLiteral("remove_column_after"));
-    connect(d->actionRemoveColumnAfter, SIGNAL(triggered(bool)),
-            SLOT(_k_slotRemoveColumnAfter()));
+    connect(d->actionRemoveColumnAfter, &QAction::triggered, this, [this]() {d->_k_slotRemoveColumnAfter();});
 
     removeMenu->addSeparator();
     d->actionRemoveCellContents = new QAction(i18n("Cell Contents"), this);
     removeMenu->addAction(d->actionRemoveCellContents);
     d->actionRemoveCellContents->setObjectName(QStringLiteral("remove_cell_contents"));
-    connect(d->actionRemoveCellContents, SIGNAL(triggered(bool)),
-            SLOT(_k_slotRemoveCellContents()));
+    connect(d->actionRemoveCellContents, &QAction::triggered, this, [this]() {d->_k_slotRemoveCellContents();});
 
     addSeparator();
 
-    d->actionMergeCell =
-        new QAction(QIcon::fromTheme(QStringLiteral("edit-table-cell-merge")),
-                    i18n("Join With Cell to the Right"), this);
+    d->actionMergeCell
+        = new QAction(QIcon::fromTheme(QStringLiteral("edit-table-cell-merge")),
+                      i18n("Join With Cell to the Right"), this);
     d->actionMergeCell->setObjectName(QStringLiteral("join_cell_to_the_right"));
-    connect(d->actionMergeCell, SIGNAL(triggered(bool)),
-            SLOT(_k_slotMergeCell()));
+    connect(d->actionMergeCell, &QAction::triggered, this, [this]() {d->_k_slotMergeCell();});
     addAction(d->actionMergeCell);
 
     d->actionMergeSelectedCells = new QAction(i18n("Join Selected Cells"), this);
     d->actionMergeSelectedCells->setObjectName(QStringLiteral("join_cell_selected_cells"));
-    connect(d->actionMergeSelectedCells, SIGNAL(triggered(bool)),
-            SLOT(_k_slotMergeSelectedCells()));
+    connect(d->actionMergeSelectedCells, &QAction::triggered, this, [this]() {d->_k_slotMergeSelectedCells();});
     addAction(d->actionMergeSelectedCells);
 
-    d->actionSplitCell =
-        new QAction(QIcon::fromTheme(QStringLiteral("edit-table-cell-split")),
-                    i18n("Split cells"), this);
+    d->actionSplitCell
+        = new QAction(QIcon::fromTheme(QStringLiteral("edit-table-cell-split")),
+                      i18n("Split cells"), this);
     d->actionSplitCell->setObjectName(QStringLiteral("split_cells"));
-    connect(d->actionSplitCell, SIGNAL(triggered(bool)),
-            SLOT(_k_slotSplitCell()));
+    connect(d->actionSplitCell, &QAction::triggered, this, [this]() {d->_k_slotSplitCell();});
     addAction(d->actionSplitCell);
 
     addSeparator();
 
     d->actionTableFormat = new QAction(i18n("Table Format..."), this);
     d->actionTableFormat->setObjectName(QStringLiteral("table_format"));
-    connect(d->actionTableFormat, SIGNAL(triggered(bool)),
-            SLOT(_k_slotTableFormat()));
+    connect(d->actionTableFormat, &QAction::triggered, this, [this]() {d->_k_slotTableFormat();});
     addAction(d->actionTableFormat);
 
     d->actionTableCellFormat = new QAction(i18n("Table Cell Format..."), this);
     d->actionTableCellFormat->setObjectName(QStringLiteral("table_cell_format"));
-    connect(d->actionTableCellFormat, SIGNAL(triggered(bool)),
-            SLOT(_k_slotTableCellFormat()));
+    connect(d->actionTableCellFormat, &QAction::triggered, this, [this]() {d->_k_slotTableCellFormat();});
     addAction(d->actionTableCellFormat);
 
-    connect(textEdit, SIGNAL(cursorPositionChanged()),
-            this, SLOT(_k_updateActions()));
+    connect(textEdit, &QTextEdit::cursorPositionChanged, this, [this]() {d->_k_updateActions(false);});
     d->_k_updateActions(true);
 }
 
@@ -553,7 +537,6 @@ void TableActionMenu::setRichTextMode(bool richTextMode)
 {
     d->richTextMode = richTextMode;
 }
-
 }
 
 #include "moc_tableactionmenu.cpp"
