@@ -69,7 +69,7 @@ public:
         backgroundColor->setEnabled(false);
         q->connect(useBackgroundColor, &QCheckBox::toggled, backgroundColor, &KColorButton::setEnabled);
 
-        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, q);
         buttonBox->button(QDialogButtonBox::Ok)->setShortcut(Qt::CTRL | Qt::Key_Return);
         q->connect(buttonBox, &QDialogButtonBox::accepted, q, &QDialog::accept);
         q->connect(buttonBox, &QDialogButtonBox::rejected, q, &QDialog::reject);
@@ -77,11 +77,11 @@ public:
         mainLayout->addWidget(buttonBox);
     }
 
-    QCheckBox *useBackgroundColor;
+    QCheckBox *useBackgroundColor = nullptr;
 
-    KColorButton *backgroundColor;
-    KComboBox *verticalAlignment;
-    TableCellFormatDialog *q;
+    KColorButton *backgroundColor = nullptr;
+    KComboBox *verticalAlignment = nullptr;
+    TableCellFormatDialog *q = nullptr;
 };
 
 TableCellFormatDialog::TableCellFormatDialog(QWidget *parent)
