@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -27,11 +27,10 @@
 
 #include <QTextLength>
 
-namespace KPIMTextEdit
-{
-
+namespace KPIMTextEdit {
 class KPIMTEXTEDIT_EXPORT TableFormatDialog : public QDialog
 {
+    Q_OBJECT
 public:
     explicit TableFormatDialog(QWidget *parent);
     ~TableFormatDialog();
@@ -68,6 +67,5 @@ private:
     class TableFormatDialogPrivate;
     TableFormatDialogPrivate *const d;
 };
-
 }
 #endif // KPIMTEXTEDIT_TABLEFORMATDIALOG_H
