@@ -55,9 +55,9 @@ private:
     void computeSizeAndResize();
     QString mMessage;
     QString mDetails;
-    QTimer *mTimer;
     QPixmap mSymbol;
-    int mLineSpacing;
+    QTimer *mTimer = nullptr;
+    int mLineSpacing = 0;
 };
 }
 
