@@ -20,7 +20,6 @@
 #include "plaintexteditfindbar.h"
 #include "texteditor/commonwidget/textfindreplacewidget.h"
 
-#include <KLocalizedString>
 #include <kmessagebox.h>
 #include <klineedit.h>
 #include <KColorScheme>
@@ -37,7 +36,7 @@ public:
     {
     }
 
-    QPlainTextEdit *mView;
+    QPlainTextEdit *mView = nullptr;
 };
 
 PlainTextEditFindBar::PlainTextEditFindBar(QPlainTextEdit *view, QWidget *parent)
