@@ -630,6 +630,21 @@ bool PlainTextEditor::handleShortcut(QKeyEvent *event)
     return false;
 }
 
+void PlainTextEditor::wheelEvent(QWheelEvent *event)
+{
+    if (QApplication::keyboardModifiers() & Qt::ControlModifier) {
+        if (event->delta() > 0) {
+            zoomIn();
+        } else if (event->delta() < 0) {
+            zoomOut();
+        }
+        event->accept();
+        return;
+    }
+    QPlainTextEdit::wheelEvent(event);
+}
+
+
 void PlainTextEditor::keyPressEvent(QKeyEvent *event)
 {
     if (handleShortcut(event)) {
