@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,13 +24,11 @@
 
 #include <QPlainTextEdit>
 
-namespace Sonnet
-{
+namespace Sonnet {
 class Highlighter;
 class SpellCheckDecorator;
 }
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class KPIMTEXTEDIT_EXPORT PlainTextEditor : public QPlainTextEdit
 {
     Q_OBJECT
@@ -96,15 +94,16 @@ protected:
     virtual void addExtraMenuEntry(QMenu *menu, QPoint pos);
 
 protected:
-    void contextMenuEvent(QContextMenuEvent *event) Q_DECL_OVERRIDE;
-    bool event(QEvent *ev) Q_DECL_OVERRIDE;
-    void keyPressEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
+    void contextMenuEvent(QContextMenuEvent *event) override;
+    bool event(QEvent *ev) override;
+    void keyPressEvent(QKeyEvent *event) override;
     bool overrideShortcut(QKeyEvent *event);
     bool handleShortcut(QKeyEvent *event);
+    void wheelEvent(QWheelEvent *event) override;
 
     virtual Sonnet::SpellCheckDecorator *createSpellCheckDecorator();
     void setHighlighter(Sonnet::Highlighter *_highLighter);
-    void focusInEvent(QFocusEvent *event) Q_DECL_OVERRIDE;
+    void focusInEvent(QFocusEvent *event) override;
     virtual void updateHighLighter();
     virtual void clearDecorator();
 
