@@ -31,30 +31,25 @@ class KPIMTextEdit::PlainTextEditorWidgetPrivate
 {
 public:
     PlainTextEditorWidgetPrivate()
-        : mFindBar(nullptr),
-          mEditor(nullptr),
-          mTextToSpeechWidget(nullptr),
-          mSliderContainer(nullptr)
     {
-
     }
 
-    KPIMTextEdit::PlainTextEditFindBar *mFindBar;
-    PlainTextEditor *mEditor;
-    KPIMTextEdit::TextToSpeechWidget *mTextToSpeechWidget;
-    KPIMTextEdit::SlideContainer *mSliderContainer;
+    KPIMTextEdit::PlainTextEditFindBar *mFindBar = nullptr;
+    PlainTextEditor *mEditor = nullptr;
+    KPIMTextEdit::TextToSpeechWidget *mTextToSpeechWidget = nullptr;
+    KPIMTextEdit::SlideContainer *mSliderContainer = nullptr;
 };
 
 PlainTextEditorWidget::PlainTextEditorWidget(PlainTextEditor *customEditor, QWidget *parent)
-    : QWidget(parent),
-      d(new KPIMTextEdit::PlainTextEditorWidgetPrivate)
+    : QWidget(parent)
+    , d(new KPIMTextEdit::PlainTextEditorWidgetPrivate)
 {
     init(customEditor);
 }
 
 PlainTextEditorWidget::PlainTextEditorWidget(QWidget *parent)
-    : QWidget(parent),
-      d(new KPIMTextEdit::PlainTextEditorWidgetPrivate)
+    : QWidget(parent)
+    , d(new KPIMTextEdit::PlainTextEditorWidgetPrivate)
 {
     init();
 }
@@ -84,7 +79,6 @@ void PlainTextEditorWidget::setPlainText(const QString &text)
     d->mEditor->setPlainText(text);
 }
 
-
 bool PlainTextEditorWidget::isEmpty() const
 {
     return d->mEditor->document()->isEmpty();
@@ -164,4 +158,3 @@ void PlainTextEditorWidget::slotFind()
         d->mFindBar->focusAndSetCursor();
     }
 }
-
