@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,8 +23,7 @@
 #include "kpimtextedit_export.h"
 #include <QWidget>
 
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class PlainTextEditor;
 class PlainTextEditorWidgetPrivate;
 class KPIMTEXTEDIT_EXPORT PlainTextEditorWidget : public QWidget
@@ -32,8 +31,8 @@ class KPIMTEXTEDIT_EXPORT PlainTextEditorWidget : public QWidget
     Q_OBJECT
     Q_PROPERTY(bool readOnly READ isReadOnly WRITE setReadOnly)
 public:
-    explicit PlainTextEditorWidget(QWidget *parent = Q_NULLPTR);
-    explicit PlainTextEditorWidget(PlainTextEditor *customEditor, QWidget *parent = Q_NULLPTR);
+    explicit PlainTextEditorWidget(QWidget *parent = nullptr);
+    explicit PlainTextEditorWidget(PlainTextEditor *customEditor, QWidget *parent = nullptr);
     ~PlainTextEditorWidget();
 
     PlainTextEditor *editor() const;
@@ -47,13 +46,14 @@ public:
     void clear();
     void setSpellCheckingConfigFileName(const QString &_fileName);
 
+    bool isEmpty() const;
 private Q_SLOTS:
     void slotFind();
     void slotReplace();
 
     void slotHideFindBar();
 private:
-    void init(PlainTextEditor *customEditor = Q_NULLPTR);
+    void init(PlainTextEditor *customEditor = nullptr);
     PlainTextEditorWidgetPrivate *const d;
 };
 }
