@@ -19,9 +19,7 @@
 
 #include "texteditor/plaintexteditor/plaintexteditorwidget.h"
 
-#include <KLocalizedString>
 #include <QApplication>
-#include <KAboutData>
 #include <QCommandLineParser>
 #include <QStandardPaths>
 
@@ -29,15 +27,10 @@ int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
     QStandardPaths::setTestModeEnabled(true);
-    KAboutData aboutData(QStringLiteral("plaintexteditor_gui"), i18n("PlainTextEditorTest_Gui"), QStringLiteral("1.0"));
-    aboutData.setShortDescription(i18n("Test for plaintexteditor widget"));
     QCommandLineParser parser;
-    KAboutData::setApplicationData(aboutData);
     parser.addVersionOption();
     parser.addHelpOption();
-    aboutData.setupCommandLine(&parser);
     parser.process(app);
-    aboutData.processCommandLine(&parser);
 
     KPIMTextEdit::PlainTextEditorWidget *w = new KPIMTextEdit::PlainTextEditorWidget();
     w->resize(800, 600);
@@ -46,4 +39,3 @@ int main(int argc, char **argv)
     delete w;
     return 0;
 }
-
