@@ -53,10 +53,10 @@ public:
     void createCompleter();
     void completeText();
     QString excludeOfCharacters;
-    QCompleter *completer;
-    QPlainTextEdit *plainTextEdit;
-    QTextEdit *textEdit;
-    TextEditorCompleter *q;
+    QCompleter *completer = nullptr;
+    QPlainTextEdit *plainTextEdit = nullptr;
+    QTextEdit *textEdit = nullptr;
+    TextEditorCompleter *q = nullptr;
 };
 
 void TextEditorCompleter::TextEditorCompleterPrivate::createCompleter()
@@ -72,7 +72,7 @@ void TextEditorCompleter::TextEditorCompleterPrivate::createCompleter()
     completer->setModelSorting(QCompleter::CaseSensitivelySortedModel);
     completer->setCaseSensitivity(Qt::CaseInsensitive);
     completer->setCompletionMode(QCompleter::PopupCompletion);
-    connect(completer, static_cast<void (QCompleter::*)(const QString &)>(&QCompleter::activated), q, &TextEditorCompleter::slotCompletion);
+    connect(completer, QOverload<const QString &>::of(&QCompleter::activated), q, &TextEditorCompleter::slotCompletion);
 }
 
 QString TextEditorCompleter::TextEditorCompleterPrivate::wordUnderCursor() const
