@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,13 +24,12 @@
 #include <QVector>
 #include <QObject>
 #include "kpimtextedit_export.h"
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class KPIMTEXTEDIT_EXPORT AbstractTextToSpeechConfigInterface : public QObject
 {
     Q_OBJECT
 public:
-    explicit AbstractTextToSpeechConfigInterface(QObject *parent = Q_NULLPTR);
+    explicit AbstractTextToSpeechConfigInterface(QObject *parent = nullptr);
     ~AbstractTextToSpeechConfigInterface();
     virtual QVector<QLocale> availableLocales() const;
     virtual QLocale locale() const;
@@ -43,4 +42,3 @@ public:
 }
 
 #endif // ABSTRACTTEXTTOSPEECHCONFIGINTERFACE_H
-
