@@ -21,8 +21,7 @@
 #define TEXTTOSPEECHWIDGETTEST_H
 
 #include <QObject>
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class TextToSpeechWidget;
 }
 class TextToSpeechWidgetTest : public QObject
