@@ -19,28 +19,18 @@
 
 #include "texttospeech/texttospeechconfigdialog.h"
 #include "texttospeech/texttospeech.h"
-#include <KLocalizedString>
 #include <QApplication>
-#include <KAboutData>
-#include <QTextEdit>
-#include <QVBoxLayout>
 #include <QCommandLineParser>
-#include <QMainWindow>
 #include <QStandardPaths>
 
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
     QStandardPaths::setTestModeEnabled(true);
-    KAboutData aboutData(QStringLiteral("texttospeechconfigdialog_gui"), i18n("texttospeechconfigdialog_Gui"), QStringLiteral("1.0"));
-    aboutData.setShortDescription(i18n("Test for config dialog text to speech"));
     QCommandLineParser parser;
-    KAboutData::setApplicationData(aboutData);
     parser.addVersionOption();
     parser.addHelpOption();
-    aboutData.setupCommandLine(&parser);
     parser.process(app);
-    aboutData.processCommandLine(&parser);
 
     KPIMTextEdit::TextToSpeechConfigDialog *w = new KPIMTextEdit::TextToSpeechConfigDialog;
 
