@@ -20,20 +20,15 @@
 #include "texttospeechconfiggui.h"
 #include "texttospeech/texttospeechconfigwidget.h"
 #include "texttospeech/texttospeech.h"
-#include <KLocalizedString>
 #include <QApplication>
-#include <KAboutData>
-#include <QTextEdit>
-#include <QVBoxLayout>
 #include <QCommandLineParser>
-#include <QMainWindow>
 #include <QStandardPaths>
+#include <QHBoxLayout>
 
 TextToSpeechConfigGui::TextToSpeechConfigGui(QWidget *parent)
     : QWidget(parent)
 {
-    QHBoxLayout *hbox = new QHBoxLayout;
-    setLayout(hbox);
+    QHBoxLayout *hbox = new QHBoxLayout(this);
     KPIMTextEdit::TextToSpeechConfigWidget *widget = new KPIMTextEdit::TextToSpeechConfigWidget(this);
     hbox->addWidget(widget);
 }
@@ -46,15 +41,10 @@ int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
     QStandardPaths::setTestModeEnabled(true);
-    KAboutData aboutData(QStringLiteral("texttospeechconfig_gui"), i18n("texttospeechconfig_Gui"), QStringLiteral("1.0"));
-    aboutData.setShortDescription(i18n("Test for config text to speech"));
     QCommandLineParser parser;
-    KAboutData::setApplicationData(aboutData);
     parser.addVersionOption();
     parser.addHelpOption();
-    aboutData.setupCommandLine(&parser);
     parser.process(app);
-    aboutData.processCommandLine(&parser);
 
     TextToSpeechConfigGui *w = new TextToSpeechConfigGui;
 
