@@ -21,9 +21,7 @@
 #include "texttospeech/texttospeech.h"
 #include <KLocalizedString>
 #include <QApplication>
-#include <KAboutData>
 #include <QTextEdit>
-#include <QVBoxLayout>
 #include <QCommandLineParser>
 #include <QMainWindow>
 #include <QAction>
@@ -68,15 +66,10 @@ int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
     QStandardPaths::setTestModeEnabled(true);
-    KAboutData aboutData(QStringLiteral("texttospeech_gui"), i18n("texttospeech_Gui"), QStringLiteral("1.0"));
-    aboutData.setShortDescription(i18n("Test for text to speech"));
     QCommandLineParser parser;
-    KAboutData::setApplicationData(aboutData);
     parser.addVersionOption();
     parser.addHelpOption();
-    aboutData.setupCommandLine(&parser);
     parser.process(app);
-    aboutData.processCommandLine(&parser);
 
     TextToSpeechGui *w = new TextToSpeechGui;
 
