@@ -28,24 +28,6 @@
 #endif
 
 namespace KPIMTextEdit {
-class TextToSpeechPrivate
-{
-public:
-    TextToSpeechPrivate()
-        : textToSpeech(new TextToSpeech)
-    {
-    }
-
-    ~TextToSpeechPrivate()
-    {
-        delete textToSpeech;
-    }
-
-    TextToSpeech *textToSpeech;
-};
-
-Q_GLOBAL_STATIC(TextToSpeechPrivate, sInstance)
-
 TextToSpeech::TextToSpeech(QObject *parent)
     : QObject(parent)
 #if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
@@ -75,8 +57,8 @@ void TextToSpeech::reloadSettings()
         connect(mTextToSpeech, &QTextToSpeech::stateChanged, this, &TextToSpeech::slotStateChanged);
     }
     mDefaultEngine = engineName;
-    mTextToSpeech->setRate(grp.readEntry("rate", 0));
-    mTextToSpeech->setPitch(grp.readEntry("pitch", 0));
+    mTextToSpeech->setRate(grp.readEntry("rate", 0.0));
+    mTextToSpeech->setPitch(grp.readEntry("pitch", 0.0));
     mTextToSpeech->setVolume(grp.readEntry("volume", 0));
     mTextToSpeech->setLocale(QLocale(grp.readEntry("localeName")));
     //It doesn't have api for it mTextToSpeech->setVoice(grp.readEntry("voice"));
@@ -85,7 +67,8 @@ void TextToSpeech::reloadSettings()
 
 TextToSpeech *TextToSpeech::self()
 {
-    return sInstance->textToSpeech; //will create it
+    static TextToSpeech s_self;
+    return &s_self;
 }
 
 void TextToSpeech::slotStateChanged()
