@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -28,9 +28,7 @@
 class QTextToSpeech;
 #endif
 
-namespace KPIMTextEdit
-{
-
+namespace KPIMTextEdit {
 class KPIMTEXTEDIT_EXPORT TextToSpeech : public QObject
 {
     Q_OBJECT
@@ -70,16 +68,14 @@ public Q_SLOTS:
 Q_SIGNALS:
     void stateChanged(TextToSpeech::State);
 
-private Q_SLOTS:
-    void slotStateChanged();
-
 private:
-    explicit TextToSpeech(QObject *parent = Q_NULLPTR);
+    void slotStateChanged();
+    explicit TextToSpeech(QObject *parent = nullptr);
     friend class TextToSpeechPrivate;
 
 #if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     QString mDefaultEngine;
-    QTextToSpeech *mTextToSpeech;
+    QTextToSpeech *mTextToSpeech = nullptr;
 #endif
 };
 }
