@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -37,12 +37,13 @@ TextToSpeechConfigDialog::TextToSpeechConfigDialog(QWidget *parent)
     mTextToSpeechConfigWidget = new TextToSpeechConfigWidget(parent);
     mainLayout->addWidget(mTextToSpeechConfigWidget);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::RestoreDefaults, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &TextToSpeechConfigDialog::slotAccepted);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &TextToSpeechConfigDialog::reject);
+    connect(buttonBox->button(QDialogButtonBox::RestoreDefaults), &QPushButton::clicked, this, &TextToSpeechConfigDialog::slotRestoreDefaults);
     mainLayout->addWidget(buttonBox);
     mTextToSpeechConfigWidget->readConfig();
     readConfig();
@@ -53,6 +54,11 @@ TextToSpeechConfigDialog::~TextToSpeechConfigDialog()
     writeConfig();
 }
 
+void TextToSpeechConfigDialog::slotRestoreDefaults()
+{
+    mTextToSpeechConfigWidget->restoreDefaults();
+}
+
 void TextToSpeechConfigDialog::readConfig()
 {
     KConfigGroup group(KSharedConfig::openConfig(), "TextToSpeechConfigDialog");
