@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -29,19 +29,19 @@ TextToSpeechConfigInterface::TextToSpeechConfigInterface(QObject *parent)
     , mTextToSpeech(new QTextToSpeech(this))
 #endif
 {
-
 }
 
 TextToSpeechConfigInterface::~TextToSpeechConfigInterface()
 {
-
 }
 
 QStringList TextToSpeechConfigInterface::availableVoices() const
 {
     QStringList lst;
 #if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
-    Q_FOREACH (const QVoice &voice, mTextToSpeech->availableVoices()) {
+    const QVector<QVoice> voices = mTextToSpeech->availableVoices();
+    lst.reserve(voices.count());
+    for (const QVoice &voice : voices) {
         lst << voice.name();
     }
 #endif
