@@ -64,19 +64,19 @@ TextToSpeechConfigWidget::TextToSpeechConfigWidget(QWidget *parent)
     mAvailableEngine = new QComboBox(this);
     mAvailableEngine->setObjectName(QStringLiteral("engine"));
     layout->addRow(i18n("Engine:"), mAvailableEngine);
-    connect(mAvailableEngine, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &TextToSpeechConfigWidget::slotEngineChanged);
-    connect(mAvailableEngine, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &TextToSpeechConfigWidget::valueChanged);
+    connect(mAvailableEngine, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &TextToSpeechConfigWidget::slotEngineChanged);
+    connect(mAvailableEngine, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &TextToSpeechConfigWidget::valueChanged);
 
     mLanguage = new KPIMTextEdit::TextToSpeechLanguageComboBox(this);
     mLanguage->setObjectName(QStringLiteral("language"));
     layout->addRow(i18n("Language:"), mLanguage);
-    connect(mAvailableEngine, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &TextToSpeechConfigWidget::slotLanguageChanged);
-    connect(mLanguage, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &TextToSpeechConfigWidget::valueChanged);
+    connect(mAvailableEngine, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &TextToSpeechConfigWidget::slotLanguageChanged);
+    connect(mLanguage, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &TextToSpeechConfigWidget::valueChanged);
 
     mVoice = new QComboBox(this);
     mVoice->setObjectName(QStringLiteral("voice"));
     layout->addRow(i18n("Voice:"), mVoice);
-    connect(mVoice, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &TextToSpeechConfigWidget::valueChanged);
+    connect(mVoice, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &TextToSpeechConfigWidget::valueChanged);
 
     QTimer::singleShot(0, this, &TextToSpeechConfigWidget::slotUpdateSettings);
 }
@@ -105,8 +105,8 @@ void TextToSpeechConfigWidget::readConfig()
 {
     KConfig config(QStringLiteral("texttospeechrc"));
     KConfigGroup grp = config.group("Settings");
-    mRate->setValue(static_cast<int>(grp.readEntry("rate", 0) * 100));
-    mPitch->setValue(static_cast<int>(grp.readEntry("pitch", 0) * 100));
+    mRate->setValue(static_cast<int>(grp.readEntry("rate", 0.0) * 100));
+    mPitch->setValue(static_cast<int>(grp.readEntry("pitch", 0.0) * 100));
     mVolume->setValue(static_cast<int>(grp.readEntry("volume", 50)));
     updateLocale();
 }
@@ -116,8 +116,8 @@ void TextToSpeechConfigWidget::writeConfig()
     KConfig config(QStringLiteral("texttospeechrc"));
     KConfigGroup grp = config.group("Settings");
     grp.writeEntry("volume", mVolume->value());
-    grp.writeEntry("rate", static_cast<double>(mRate->value() / 100));
-    grp.writeEntry("pitch", static_cast<double>(mPitch->value() / 100));
+    grp.writeEntry("rate", (static_cast<int>((static_cast<double>(mRate->value()) / 100.0))));
+    grp.writeEntry("pitch", (static_cast<int>((static_cast<double>(mPitch->value()) / 100.0))));
     grp.writeEntry("localeName", mLanguage->currentData().toLocale().name());
     grp.writeEntry("engine", mAvailableEngine->currentData().toString());
     grp.writeEntry("voice", mVoice->currentData().toString());
