@@ -28,30 +28,28 @@
 
 using namespace KPIMTextEdit;
 
-static bool isCharFormatFormatted(const QTextCharFormat &format, const QFont &defaultFont,
-                                  const QTextCharFormat &defaultBlockFormat)
+static bool isCharFormatFormatted(const QTextCharFormat &format, const QFont &defaultFont, const QTextCharFormat &defaultBlockFormat)
 {
-    if (!format.anchorHref().isEmpty() ||
-            format.font() != defaultFont ||
-            format.isAnchor() ||
-            format.verticalAlignment() != defaultBlockFormat.verticalAlignment() ||
-            format.layoutDirection() != defaultBlockFormat.layoutDirection() ||
-            format.underlineStyle() != defaultBlockFormat.underlineStyle() ||
-            format.foreground().color() != defaultBlockFormat.foreground().color() ||
-            format.background().color() != defaultBlockFormat.background().color()) {
+    if (!format.anchorHref().isEmpty()
+        || format.font() != defaultFont
+        || format.isAnchor()
+        || format.verticalAlignment() != defaultBlockFormat.verticalAlignment()
+        || format.layoutDirection() != defaultBlockFormat.layoutDirection()
+        || format.underlineStyle() != defaultBlockFormat.underlineStyle()
+        || format.foreground().color() != defaultBlockFormat.foreground().color()
+        || format.background().color() != defaultBlockFormat.background().color()) {
         return true;
     }
 
     return false;
 }
 
-static bool isBlockFormatFormatted(const QTextBlockFormat &format,
-                                   const QTextBlockFormat &defaultFormat)
+static bool isBlockFormatFormatted(const QTextBlockFormat &format, const QTextBlockFormat &defaultFormat)
 {
-    if (format.alignment() != defaultFormat.alignment() ||
-            format.layoutDirection() != defaultFormat.layoutDirection() ||
-            format.indent() != defaultFormat.indent() ||
-            format.textIndent() != defaultFormat.textIndent()) {
+    if (format.alignment() != defaultFormat.alignment()
+        || format.layoutDirection() != defaultFormat.layoutDirection()
+        || format.indent() != defaultFormat.indent()
+        || format.textIndent() != defaultFormat.textIndent()) {
         return true;
     }
 
@@ -61,8 +59,8 @@ static bool isBlockFormatFormatted(const QTextBlockFormat &format,
 /// @return true if the format represents a list, table, image or something like that.
 static bool isSpecial(const QTextFormat &charFormat)
 {
-    return charFormat.isFrameFormat() || charFormat.isImageFormat() ||
-           charFormat.isListFormat() || charFormat.isTableFormat() || charFormat.isTableCellFormat();
+    return charFormat.isFrameFormat() || charFormat.isImageFormat()
+           || charFormat.isListFormat() || charFormat.isTableFormat() || charFormat.isTableCellFormat();
 }
 
 bool TextUtils::containsFormatting(const QTextDocument *document)
@@ -78,13 +76,12 @@ bool TextUtils::containsFormatting(const QTextDocument *document)
 
     QTextBlock block = document->firstBlock();
     while (block.isValid()) {
-
         if (isBlockFormatFormatted(block.blockFormat(), defaultBlockFormat)) {
             return true;
         }
 
-        if (isSpecial(block.charFormat()) || isSpecial(block.blockFormat()) ||
-                block.textList()) {
+        if (isSpecial(block.charFormat()) || isSpecial(block.blockFormat())
+            || block.textList()) {
             return true;
         }
 
@@ -120,7 +117,7 @@ QString TextUtils::flowText(QString &wrappedText, const QString &indent, int max
 
     if (maxLength <= indent.length()) {
         qCWarning(KPIMTEXTEDIT_LOG) << "indent was set to a string that is longer or the same length "
-                   << "as maxLength, setting maxLength to indent.length() + 1";
+                                    << "as maxLength, setting maxLength to indent.length() + 1";
         maxLength = indent.length() + 1;
     }
 
